netapp_ontap.models.software_update_details API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.software_update_details`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SoftwareUpdateDetailsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SoftwareUpdateDetails object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `elapsed_duration: Size GET`

    Elapsed duration for each update phase

    Example: 2100

  `estimated_duration: Size GET`

    Estimated duration for each update phase

    Example: 4620

  `node: SoftwareUpdateDetailsReferenceNode GET POST PATCH`

    The node field of the software_update_details.

  `phase: str GET`

    Phase details

    Example: Post-update checks

  `state: str GET`

    State of the update phase

    Valid choices:

    - in_progress
    - waiting
    - paused_by_user
    - paused_on_error
    - completed
    - canceled
    - failed
    - pause_pending
    - cancel_pending